'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _display = require('./display');

Object.keys(_display).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _display[key];
    }
  });
});

var _currency = require('./currency');

Object.keys(_currency).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _currency[key];
    }
  });
});

var _intl = require('intl');

var _intl2 = _interopRequireDefault(_intl);

var _isnumber = require('./helpers/isnumber');

var _isnumber2 = _interopRequireDefault(_isnumber);

var _handler = require('./helpers/handler');

var _handler2 = _interopRequireDefault(_handler);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var normalize = function normalize(value) {
  return Math.round(value * 100);
};

var denormalize = function denormalize(value) {
  return value / 100;
};

var DEFAULT_LOCALE = 'en';

var DEFAULT_CURRENCY = _currency.CURRENCY_USD;

var DEFAULT_CURRENCY_DISPLAY = _display.DISPLAY_SYMBOL;

var DEFAULT_OPTIONS = { minimumFractionDigits: 2, maximumFractionDigits: 2 };

var sum = function sum(newValue, oldValue) {
  return newValue + denormalize(oldValue);
};

var subtract = function subtract(newValue, oldValue) {
  return denormalize(oldValue) - newValue;
};

/** Class representing a Wallet. */

var Wallet =

/**
* Create a new Wallet object with the initial value.
* @param {number} value - The value to put on wallet
* @param {number} [locale=en] - The locale for this wallet
* @param {number} [currency=USD] - The currency to use in currency formatting.
*/
function Wallet(value) {
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_LOCALE;
  var currency = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : DEFAULT_CURRENCY;

  _classCallCheck(this, Wallet);

  _initialiseProps.call(this);

  if (!(0, _isnumber2.default)(value)) {
    throw new Error('Value should be a number');
  }

  this.value = normalize(value);
  this.locale = locale;
  this.currency = currency;
}

/**
* Create a new Wallet object with the initial value.
* @param {number} value - A value to put on wallet
* @param {number} [locale=en] - The locale for this wallet
* @param {number} [currency=USD] - The currency to use in currency formatting.
* @return {Wallet} The wallet with value
*/


/**
* Create a new Wallet object from String value
* @param {string} string - A value to put on wallet
* @param {number} [locale=en] - The locale for this wallet
* @param {number} [currency=USD] - The currency to use in currency formatting.
* @return {Wallet} The wallet with value
*/


/**
 * Adds a value to wallet
 * @param {number} value - A value to put on wallet
 * @return {Wallet} The wallet with new value
 */


/**
 * Subtract a value to wallet
 * @param {number} value - A value to remove from wallet
 * @return {Wallet} The wallet with new value
 */


/**
* Return a formatted currency of Wallet
* @param {number} [currencyDisplay=symbol] - How to display the currency in currency formatting.
* @param {number} [currency=USD] - The currency to use in currency formatting.
* @return {string} currency number of wallet
*/


/**
* Formatted value of Wallet
* @return {string} formatted number of wallet
*/
;

Wallet.init = function () {
  var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      locale = _ref.locale,
      currency = _ref.currency;

  return new Wallet(value, locale, currency);
};

Wallet.fromString = function () {
  var string = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '0';

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      locale = _ref2.locale,
      currency = _ref2.currency;

  var value = Number.parseFloat(string);
  return new Wallet(value, locale, currency);
};

var _initialiseProps = function _initialiseProps() {
  var _this = this;

  this.add = function (value) {
    return (0, _handler2.default)(sum.bind(_this, value), _this);
  };

  this.subtract = function (value) {
    return (0, _handler2.default)(subtract.bind(_this, value), _this);
  };

  this.toCurrency = function () {
    var currencyDisplay = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DEFAULT_CURRENCY_DISPLAY;

    var _ref3 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        currency = _ref3.currency;

    var options = _extends({}, DEFAULT_OPTIONS, {
      style: 'currency',
      currency: currency || _this.currency,
      currencyDisplay: currencyDisplay
    });
    var intl = new _intl2.default.NumberFormat(_this.locale, options);
    return intl.format(denormalize(_this.value));
  };

  this.toString = function () {
    var intl = new _intl2.default.NumberFormat(_this.locale, DEFAULT_OPTIONS);
    return intl.format(denormalize(_this.value));
  };
};

exports.default = Wallet;